use mongod::{
    derive::{Model, Referencable},
    Model, Validate,
};
use serde::{Deserialize, Serialize};
use serde_json::json;

use crate::route::ToAPI;

#[derive(Debug, Clone, Serialize, Deserialize, Model, Referencable)]
pub struct Artist {
    pub _id: String,
    pub name: String,
}

impl Artist {
    pub async fn create(name: &str) -> Self {
        let a = Artist {
            _id: uuid::Uuid::new_v4().to_string(),
            name: name.to_string(),
        };
        a.insert().await.unwrap();
        a
    }
}

impl ToAPI for Artist {
    async fn api(&self) -> serde_json::Value {
        json!({
            "id": &self._id,
            "name": &self.name
        })
    }
}

impl Validate for Artist {
    async fn validate(&self) -> Result<(), String> {
        Ok(())
    }
}
